CloudBuild

Struct CloudBuild 

pub struct CloudBuild { /* private fields */ }
Implements a client for the Cloud Build API.

Example

use google_cloud_gax::paginator::ItemPaginator as _;
    let client = CloudBuild::builder().build().await?;
    let parent = "parent_value";
    let mut list = client.list_builds()
        .set_parent(parent)
        .by_item();
    while let Some(item) = list.next().await.transpose()? {
        println!("{:?}", item);
    }

Service Description

Creates and manages builds on Google Cloud Platform.

The main concept used by this API is a Build, which describes the location of the source to build, how to build the source, and where to store the built artifacts, if any.

A user can list previously-requested builds or get builds by their ID to determine the status of the build.

Configuration

To configure CloudBuild use the with_* methods in the type returned by builder(). The default configuration should work for most applications. Common configuration changes include

  • with_endpoint(): by default this client uses the global default endpoint (https://cloudbuild.googleapis.com). Applications using regional endpoints or running in restricted networks (e.g. a network configured override this default.
  • with_credentials(): by default this client uses Application Default Credentials. Applications using custom authentication may need to override this default.

Pooling and Cloning

CloudBuild holds a connection pool internally, it is advised to create one and reuse it. You do not need to wrap CloudBuild in an Rc or Arc to reuse it, because it already uses an Arc internally.

Implementations

Source

impl CloudBuild

pub fn builder() -> ClientBuilder

Returns a builder for CloudBuild.

let client = CloudBuild::builder().build().await?;
pub fn from_stub<T>(stub: T) -> Self
where T: CloudBuild + 'static,

Creates a new client from the provided stub.

The most common case for calling this function is in tests mocking the client’s behavior.

pub fn create_build(&self) -> CreateBuild

Starts a build with the specified configuration.

This method returns a long-running Operation, which includes the build ID. Pass the build ID to GetBuild to determine the build status (such as SUCCESS or FAILURE).

Long running operations

This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.

Example
use google_cloud_lro::Poller;
use google_cloud_build_v1::model::Build;
use google_cloud_build_v1::Result;
async fn sample(
   client: &CloudBuild, parent: &str
) -> Result<()> {
    let response = client.create_build()
        .set_parent(parent)
        .set_build(
            Build::new()/* set fields */
        )
        .poller().until_done().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn get_build(&self) -> GetBuild

Returns information about a previously requested build.

The Build that is returned includes its status (such as SUCCESS, FAILURE, or WORKING), and timing information.

Example
use google_cloud_build_v1::Result;
async fn sample(
   client: &CloudBuild, name: &str
) -> Result<()> {
    let response = client.get_build()
        .set_name(name)
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn list_builds(&self) -> ListBuilds

Lists previously requested builds.

Previously requested builds may still be in-progress, or may have finished successfully or unsuccessfully.

Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_build_v1::Result;
async fn sample(
   client: &CloudBuild, parent: &str
) -> Result<()> {
    let mut list = client.list_builds()
        .set_parent(parent)
        .by_item();
    while let Some(item) = list.next().await.transpose()? {
        println!("{:?}", item);
    }
    Ok(())
}
pub fn cancel_build(&self) -> CancelBuild

Cancels a build in progress.

Example
use google_cloud_build_v1::Result;
async fn sample(
   client: &CloudBuild
) -> Result<()> {
    let response = client.cancel_build()
        /* set fields */
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn retry_build(&self) -> RetryBuild

Creates a new build based on the specified build.

This method creates a new build using the original build request, which may or may not result in an identical build.

For triggered builds:

  • Triggered builds resolve to a precise revision; therefore a retry of a triggered build will result in a build that uses the same revision.

For non-triggered builds that specify RepoSource:

  • If the original build built from the tip of a branch, the retried build will build from the tip of that branch, which may not be the same revision as the original build.
  • If the original build specified a commit sha or revision ID, the retried build will use the identical source.

For builds that specify StorageSource:

  • If the original build pulled source from Cloud Storage without specifying the generation of the object, the new build will use the current object, which may be different from the original build source.
  • If the original build pulled source from Cloud Storage and specified the generation of the object, the new build will attempt to use the same object, which may or may not be available depending on the bucket’s lifecycle management settings.
Long running operations

This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.

Example
use google_cloud_lro::Poller;
use google_cloud_build_v1::Result;
async fn sample(
   client: &CloudBuild
) -> Result<()> {
    let response = client.retry_build()
        /* set fields */
        .poller().until_done().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn approve_build(&self) -> ApproveBuild

Approves or rejects a pending build.

If approved, the returned long-running operation (LRO) will be analogous to the LRO returned from a CreateBuild call.

If rejected, the returned LRO will be immediately done.

Long running operations

This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.

Example
use google_cloud_lro::Poller;
use google_cloud_build_v1::Result;
async fn sample(
   client: &CloudBuild
) -> Result<()> {
    let response = client.approve_build()
        /* set fields */
        .poller().until_done().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn create_build_trigger(&self) -> CreateBuildTrigger

Creates a new BuildTrigger.

Example
use google_cloud_build_v1::Result;
async fn sample(
   client: &CloudBuild
) -> Result<()> {
    let response = client.create_build_trigger()
        /* set fields */
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn get_build_trigger(&self) -> GetBuildTrigger

Returns information about a BuildTrigger.

Example
use google_cloud_build_v1::Result;
async fn sample(
   client: &CloudBuild
) -> Result<()> {
    let response = client.get_build_trigger()
        /* set fields */
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn list_build_triggers(&self) -> ListBuildTriggers

Lists existing BuildTriggers.

Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_build_v1::Result;
async fn sample(
   client: &CloudBuild, parent: &str
) -> Result<()> {
    let mut list = client.list_build_triggers()
        .set_parent(parent)
        .by_item();
    while let Some(item) = list.next().await.transpose()? {
        println!("{:?}", item);
    }
    Ok(())
}
pub fn delete_build_trigger(&self) -> DeleteBuildTrigger

Deletes a BuildTrigger by its project ID and trigger ID.

Example
use google_cloud_build_v1::Result;
async fn sample(
   client: &CloudBuild
) -> Result<()> {
    client.delete_build_trigger()
        /* set fields */
        .send().await?;
    Ok(())
}
pub fn update_build_trigger(&self) -> UpdateBuildTrigger

Updates a BuildTrigger by its project ID and trigger ID.

Example
use google_cloud_build_v1::Result;
async fn sample(
   client: &CloudBuild
) -> Result<()> {
    let response = client.update_build_trigger()
        /* set fields */
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn run_build_trigger(&self) -> RunBuildTrigger

Runs a BuildTrigger at a particular source revision.

To run a regional or global trigger, use the POST request that includes the location endpoint in the path (ex. v1/projects/{projectId}/locations/{region}/triggers/{triggerId}:run). The POST request that does not include the location endpoint in the path can only be used when running global triggers.

Long running operations

This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.

Example
use google_cloud_lro::Poller;
use google_cloud_build_v1::Result;
async fn sample(
   client: &CloudBuild
) -> Result<()> {
    let response = client.run_build_trigger()
        /* set fields */
        .poller().until_done().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn receive_trigger_webhook(&self) -> ReceiveTriggerWebhook

ReceiveTriggerWebhook [Experimental] is called when the API receives a webhook request targeted at a specific trigger.

Example
use google_cloud_build_v1::Result;
async fn sample(
   client: &CloudBuild
) -> Result<()> {
    let response = client.receive_trigger_webhook()
        /* set fields */
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn create_worker_pool(&self) -> CreateWorkerPool

Creates a WorkerPool.

Long running operations

This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.

Example
use google_cloud_lro::Poller;
use google_cloud_build_v1::model::WorkerPool;
use google_cloud_build_v1::Result;
async fn sample(
   client: &CloudBuild, parent: &str
) -> Result<()> {
    let response = client.create_worker_pool()
        .set_parent(parent)
        .set_worker_pool(
            WorkerPool::new()/* set fields */
        )
        .poller().until_done().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn get_worker_pool(&self) -> GetWorkerPool

Returns details of a WorkerPool.

Example
use google_cloud_build_v1::Result;
async fn sample(
   client: &CloudBuild, name: &str
) -> Result<()> {
    let response = client.get_worker_pool()
        .set_name(name)
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn delete_worker_pool(&self) -> DeleteWorkerPool

Deletes a WorkerPool.

Long running operations

This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.

Example
use google_cloud_lro::Poller;
use google_cloud_build_v1::Result;
async fn sample(
   client: &CloudBuild, name: &str
) -> Result<()> {
    client.delete_worker_pool()
        .set_name(name)
        .poller().until_done().await?;
    Ok(())
}
pub fn update_worker_pool(&self) -> UpdateWorkerPool

Updates a WorkerPool.

Long running operations

This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.

Example
use google_cloud_lro::Poller;
use google_cloud_wkt::FieldMask;
use google_cloud_build_v1::model::WorkerPool;
use google_cloud_build_v1::Result;
async fn sample(
   client: &CloudBuild, name: &str
) -> Result<()> {
    let response = client.update_worker_pool()
        .set_worker_pool(
            WorkerPool::new().set_name(name)/* set fields */
        )
        .set_update_mask(FieldMask::default().set_paths(["updated.field.path1", "updated.field.path2"]))
        .poller().until_done().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn list_worker_pools(&self) -> ListWorkerPools

Lists WorkerPools.

Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_build_v1::Result;
async fn sample(
   client: &CloudBuild, parent: &str
) -> Result<()> {
    let mut list = client.list_worker_pools()
        .set_parent(parent)
        .by_item();
    while let Some(item) = list.next().await.transpose()? {
        println!("{:?}", item);
    }
    Ok(())
}
pub fn get_default_service_account(&self) -> GetDefaultServiceAccount

Returns the DefaultServiceAccount used by the project.

Example
use google_cloud_build_v1::Result;
async fn sample(
   client: &CloudBuild, name: &str
) -> Result<()> {
    let response = client.get_default_service_account()
        .set_name(name)
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn get_operation(&self) -> GetOperation

Provides the Operations service functionality in this service.

Example
use google_cloud_build_v1::Result;
async fn sample(
   client: &CloudBuild
) -> Result<()> {
    let response = client.get_operation()
        /* set fields */
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn cancel_operation(&self) -> CancelOperation

Provides the Operations service functionality in this service.

Example
use google_cloud_build_v1::Result;
async fn sample(
   client: &CloudBuild
) -> Result<()> {
    client.cancel_operation()
        /* set fields */
        .send().await?;
    Ok(())
}