#[non_exhaustive]pub struct ArtifactObjects {
pub location: String,
pub paths: Vec<String>,
pub timing: Option<TimeSpan>,
/* private fields */
}Expand description
Files in the workspace to upload to Cloud Storage upon successful completion of all build steps.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.location: StringCloud Storage bucket and optional object path, in the form “gs://bucket/path/to/somewhere/”. (see Bucket Name Requirements).
Files in the workspace matching any path pattern will be uploaded to Cloud Storage with this location as a prefix.
paths: Vec<String>Path globs used to match files in the build’s workspace.
timing: Option<TimeSpan>Output only. Stores timing information for pushing all artifact objects.
Implementations
Sourceimpl ArtifactObjects
impl ArtifactObjects
Sourcepub fn set_location<T: Into<String>>(self, v: T) -> Self
pub fn set_location<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_timing<T>(self, v: T) -> Self
pub fn set_timing<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_timing<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_timing<T>(self, v: Option<T>) -> Self