GoModule

Struct GoModule 

#[non_exhaustive]
pub struct GoModule { pub repository_name: String, pub repository_location: String, pub repository_project_id: String, pub source_path: String, pub module_path: String, pub module_version: String, /* private fields */ }
Go module to upload to Artifact Registry upon successful completion of all build steps. A module refers to all dependencies in a go.mod file.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
repository_name: String

Optional. Artifact Registry repository name.

Specified Go modules will be zipped and uploaded to Artifact Registry with this location as a prefix. e.g. my-go-repo

repository_location: String

Optional. Location of the Artifact Registry repository. i.e. us-east1 Defaults to the build’s location.

repository_project_id: String

Optional. Project ID of the Artifact Registry repository. Defaults to the build project.

source_path: String

Optional. Source path of the go.mod file in the build’s workspace. If not specified, this will default to the current directory. e.g. ~/code/go/mypackage

module_path: String

Optional. The Go module’s “module path”. e.g. example.com/foo/v2

module_version: String

Optional. The Go module’s semantic version in the form vX.Y.Z. e.g. v0.1.1 Pre-release identifiers can also be added by appending a dash and dot separated ASCII alphanumeric characters and hyphens. e.g. v0.2.3-alpha.x.12m.5

Implementations

Source

impl GoModule

pub fn new() -> Self

Creates a new default instance.

pub fn set_repository_name<T: Into<String>>(self, v: T) -> Self

Sets the value of repository_name.

Example
let x = GoModule::new().set_repository_name("example");
pub fn set_repository_location<T: Into<String>>(self, v: T) -> Self

Sets the value of repository_location.

Example
let x = GoModule::new().set_repository_location("example");
pub fn set_repository_project_id<T: Into<String>>(self, v: T) -> Self

Sets the value of repository_project_id.

Example
let x = GoModule::new().set_repository_project_id("example");
pub fn set_source_path<T: Into<String>>(self, v: T) -> Self

Sets the value of source_path.

Example
let x = GoModule::new().set_source_path("example");
pub fn set_module_path<T: Into<String>>(self, v: T) -> Self

Sets the value of module_path.

Example
let x = GoModule::new().set_module_path("example");
pub fn set_module_version<T: Into<String>>(self, v: T) -> Self

Sets the value of module_version.

Example
let x = GoModule::new().set_module_version("example");