#[non_exhaustive]pub enum Status {
Unknown,
Pending,
Queued,
Working,
Success,
Failure,
InternalError,
Timeout,
Cancelled,
Expired,
UnknownValue(UnknownValue),
}Expand description
Possible status of a build or build step.
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Unknown
Status of the build is unknown.
Pending
Build has been created and is pending execution and queuing. It has not been queued.
Queued
Build or step is queued; work has not yet begun.
Working
Build or step is being executed.
Success
Build or step finished successfully.
Failure
Build or step failed to complete successfully.
InternalError
Build or step failed due to an internal cause.
Timeout
Build or step took longer than was allowed.
Cancelled
Build or step was canceled by a user.
Expired
Build was enqueued for longer than the value of queue_ttl.
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using Status::value or Status::name.
Implementations