#[non_exhaustive]pub enum LoggingMode {
LoggingUnspecified,
Legacy,
GcsOnly,
StackdriverOnly,
CloudLoggingOnly,
None,
UnknownValue(UnknownValue),
}Expand description
Specifies the logging mode.
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
LoggingUnspecified
The service determines the logging mode. The default is LEGACY. Do not
rely on the default logging behavior as it may change in the future.
Legacy
Build logs are stored in Cloud Logging and Cloud Storage.
GcsOnly
Build logs are stored in Cloud Storage.
StackdriverOnly
This option is the same as CLOUD_LOGGING_ONLY.
CloudLoggingOnly
Build logs are stored in Cloud Logging. Selecting this option will not allow logs streaming.
None
Turn off all logging. No build logs will be captured.
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using LoggingMode::value or LoggingMode::name.
Implementations