#[non_exhaustive]pub struct PoolOption {
pub name: String,
/* private fields */
}Expand description
Details about how a build should be executed on a WorkerPool.
See running builds in a private pool for more information.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringThe WorkerPool resource to execute the build on.
You must have cloudbuild.workerpools.use on the project hosting the
WorkerPool.
Format projects/{project}/locations/{location}/workerPools/{workerPoolId}
Implementations