#[non_exhaustive]pub struct GitSourceRepository {
pub repotype: Option<Repotype>,
/* private fields */
}Expand description
A repository for a git source.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.repotype: Option<Repotype>The type of git source repo (url or dev connect).
Implementations
Sourceimpl GitSourceRepository
impl GitSourceRepository
pub fn new() -> Self
Sourcepub fn set_repotype<T: Into<Option<Repotype>>>(self, v: T) -> Self
pub fn set_repotype<T: Into<Option<Repotype>>>(self, v: T) -> Self
Sourcepub fn url(&self) -> Option<&String>
pub fn url(&self) -> Option<&String>
The value of repotype
if it holds a Url, None if the field is not set or
holds a different branch.
Sourcepub fn developer_connect(&self) -> Option<&String>
pub fn developer_connect(&self) -> Option<&String>
The value of repotype
if it holds a DeveloperConnect, None if the field is not set or
holds a different branch.
Sourcepub fn set_developer_connect<T: Into<String>>(self, v: T) -> Self
pub fn set_developer_connect<T: Into<String>>(self, v: T) -> Self