#[non_exhaustive]pub struct DeleteWorkerPoolRequest {
pub name: String,
pub etag: String,
pub allow_missing: bool,
pub validate_only: bool,
/* private fields */
}Expand description
Request to delete a WorkerPool.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringRequired. The name of the WorkerPool to delete.
Format:
projects/{project}/locations/{location}/workerPools/{workerPool}.
etag: StringOptional. If provided, it must match the server’s etag on the workerpool for the request to be processed.
allow_missing: boolIf set to true, and the WorkerPool is not found, the request will succeed
but no action will be taken on the server.
validate_only: boolIf set, validate the request and preview the response, but do not actually post it.
Implementations
Sourceimpl DeleteWorkerPoolRequest
impl DeleteWorkerPoolRequest
Sourcepub fn set_allow_missing<T: Into<bool>>(self, v: T) -> Self
pub fn set_allow_missing<T: Into<bool>>(self, v: T) -> Self
Sets the value of allow_missing.
Example
ⓘ
let x = DeleteWorkerPoolRequest::new().set_allow_missing(true);Sourcepub fn set_validate_only<T: Into<bool>>(self, v: T) -> Self
pub fn set_validate_only<T: Into<bool>>(self, v: T) -> Self
Sets the value of validate_only.
Example
ⓘ
let x = DeleteWorkerPoolRequest::new().set_validate_only(true);Trait Implementations
Sourceimpl Clone for DeleteWorkerPoolRequest
impl Clone for DeleteWorkerPoolRequest
Sourcefn clone(&self) -> DeleteWorkerPoolRequest
fn clone(&self) -> DeleteWorkerPoolRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DeleteWorkerPoolRequest
impl Debug for DeleteWorkerPoolRequest
Sourceimpl Default for DeleteWorkerPoolRequest
impl Default for DeleteWorkerPoolRequest
Sourcefn default() -> DeleteWorkerPoolRequest
fn default() -> DeleteWorkerPoolRequest
Returns the “default value” for a type. Read more
Sourceimpl Message for DeleteWorkerPoolRequest
impl Message for DeleteWorkerPoolRequest
Sourceimpl PartialEq for DeleteWorkerPoolRequest
impl PartialEq for DeleteWorkerPoolRequest
impl StructuralPartialEq for DeleteWorkerPoolRequest