#[non_exhaustive]pub struct ListBuildTriggersRequest {
pub parent: String,
pub project_id: String,
pub page_size: i32,
pub page_token: String,
/* private fields */
}Expand description
Request to list existing BuildTriggers.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringThe parent of the collection of Triggers.
Format: projects/{project}/locations/{location}
project_id: StringRequired. ID of the project for which to list BuildTriggers.
page_size: i32Number of results to return in the list.
page_token: StringToken to provide to skip to a particular spot in the list.
Implementations
Sourceimpl ListBuildTriggersRequest
impl ListBuildTriggersRequest
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_project_id<T: Into<String>>(self, v: T) -> Self
pub fn set_project_id<T: Into<String>>(self, v: T) -> Self
Sets the value of project_id.
Example
ⓘ
let x = ListBuildTriggersRequest::new().set_project_id("example");Sourcepub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
pub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
Sourcepub fn set_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_page_token<T: Into<String>>(self, v: T) -> Self
Sets the value of page_token.
Example
ⓘ
let x = ListBuildTriggersRequest::new().set_page_token("example");Trait Implementations
Sourceimpl Clone for ListBuildTriggersRequest
impl Clone for ListBuildTriggersRequest
Sourcefn clone(&self) -> ListBuildTriggersRequest
fn clone(&self) -> ListBuildTriggersRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ListBuildTriggersRequest
impl Debug for ListBuildTriggersRequest
Sourceimpl Default for ListBuildTriggersRequest
impl Default for ListBuildTriggersRequest
Sourcefn default() -> ListBuildTriggersRequest
fn default() -> ListBuildTriggersRequest
Returns the “default value” for a type. Read more
Sourceimpl Message for ListBuildTriggersRequest
impl Message for ListBuildTriggersRequest
Sourceimpl PartialEq for ListBuildTriggersRequest
impl PartialEq for ListBuildTriggersRequest
impl StructuralPartialEq for ListBuildTriggersRequest