#[non_exhaustive]pub struct ListBuildsRequest {
pub parent: String,
pub project_id: String,
pub page_size: i32,
pub page_token: String,
pub filter: String,
/* private fields */
}Expand description
Request to list builds.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringThe parent of the collection of Builds.
Format: projects/{project}/locations/{location}
project_id: StringRequired. ID of the project.
page_size: i32Number of results to return in the list.
page_token: StringThe page token for the next page of Builds.
If unspecified, the first page of results is returned.
If the token is rejected for any reason, INVALID_ARGUMENT will be thrown. In this case, the token should be discarded, and pagination should be restarted from the first page of results.
See https://google.aip.dev/158 for more.
filter: StringThe raw filter text to constrain the results.
Implementations
Sourceimpl ListBuildsRequest
impl ListBuildsRequest
pub fn new() -> Self
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_project_id<T: Into<String>>(self, v: T) -> Self
pub fn set_project_id<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
pub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
Sourcepub fn set_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_page_token<T: Into<String>>(self, v: T) -> Self