#[non_exhaustive]pub struct WorkerPool {
pub name: String,
pub display_name: String,
pub uid: String,
pub annotations: HashMap<String, String>,
pub create_time: Option<Timestamp>,
pub update_time: Option<Timestamp>,
pub delete_time: Option<Timestamp>,
pub state: State,
pub etag: String,
pub config: Option<Config>,
/* private fields */
}Expand description
Configuration for a WorkerPool.
Cloud Build owns and maintains a pool of workers for general use and have no access to a project’s private network. By default, builds submitted to Cloud Build will use a worker from this pool.
If your build needs access to resources on a private network,
create and use a WorkerPool to run your builds. Private WorkerPools give
your builds access to any single VPC network that you
administer, including any on-prem resources connected to that VPC
network. For an overview of private pools, see
Private pools
overview.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringOutput only. The resource name of the WorkerPool, with format
projects/{project}/locations/{location}/workerPools/{worker_pool}.
The value of {worker_pool} is provided by worker_pool_id in
CreateWorkerPool request and the value of {location} is determined by
the endpoint accessed.
display_name: StringA user-specified, human-readable name for the WorkerPool. If provided,
this value must be 1-63 characters.
uid: StringOutput only. A unique identifier for the WorkerPool.
annotations: HashMap<String, String>User specified annotations. See https://google.aip.dev/128#annotations for more details such as format and size limitations.
create_time: Option<Timestamp>Output only. Time at which the request to create the WorkerPool was
received.
update_time: Option<Timestamp>Output only. Time at which the request to update the WorkerPool was
received.
delete_time: Option<Timestamp>Output only. Time at which the request to delete the WorkerPool was
received.
state: StateOutput only. WorkerPool state.
etag: StringOutput only. Checksum computed by the server. May be sent on update and delete requests to ensure that the client has an up-to-date value before proceeding.
config: Option<Config>Configuration for the WorkerPool.
Implementations
Sourceimpl WorkerPool
impl WorkerPool
Sourcepub fn set_display_name<T: Into<String>>(self, v: T) -> Self
pub fn set_display_name<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_annotations<T, K, V>(self, v: T) -> Self
pub fn set_annotations<T, K, V>(self, v: T) -> Self
Sets the value of annotations.
Example
let x = WorkerPool::new().set_annotations([
("key0", "abc"),
("key1", "xyz"),
]);Sourcepub fn set_create_time<T>(self, v: T) -> Self
pub fn set_create_time<T>(self, v: T) -> Self
Sets the value of create_time.
Example
use wkt::Timestamp;
let x = WorkerPool::new().set_create_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of create_time.
Example
use wkt::Timestamp;
let x = WorkerPool::new().set_or_clear_create_time(Some(Timestamp::default()/* use setters */));
let x = WorkerPool::new().set_or_clear_create_time(None::<Timestamp>);Sourcepub fn set_update_time<T>(self, v: T) -> Self
pub fn set_update_time<T>(self, v: T) -> Self
Sets the value of update_time.
Example
use wkt::Timestamp;
let x = WorkerPool::new().set_update_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of update_time.
Example
use wkt::Timestamp;
let x = WorkerPool::new().set_or_clear_update_time(Some(Timestamp::default()/* use setters */));
let x = WorkerPool::new().set_or_clear_update_time(None::<Timestamp>);Sourcepub fn set_delete_time<T>(self, v: T) -> Self
pub fn set_delete_time<T>(self, v: T) -> Self
Sets the value of delete_time.
Example
use wkt::Timestamp;
let x = WorkerPool::new().set_delete_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_delete_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_delete_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of delete_time.
Example
use wkt::Timestamp;
let x = WorkerPool::new().set_or_clear_delete_time(Some(Timestamp::default()/* use setters */));
let x = WorkerPool::new().set_or_clear_delete_time(None::<Timestamp>);Sourcepub fn set_config<T: Into<Option<Config>>>(self, v: T) -> Self
pub fn set_config<T: Into<Option<Config>>>(self, v: T) -> Self
Sets the value of config.
Note that all the setters affecting config are mutually
exclusive.
Example
use google_cloud_build_v1::model::PrivatePoolV1Config;
let x = WorkerPool::new().set_config(Some(
google_cloud_build_v1::model::worker_pool::Config::PrivatePoolV1Config(PrivatePoolV1Config::default().into())));Sourcepub fn private_pool_v1_config(&self) -> Option<&Box<PrivatePoolV1Config>>
pub fn private_pool_v1_config(&self) -> Option<&Box<PrivatePoolV1Config>>
The value of config
if it holds a PrivatePoolV1Config, None if the field is not set or
holds a different branch.
Sourcepub fn set_private_pool_v1_config<T: Into<Box<PrivatePoolV1Config>>>(
self,
v: T,
) -> Self
pub fn set_private_pool_v1_config<T: Into<Box<PrivatePoolV1Config>>>( self, v: T, ) -> Self
Sets the value of config
to hold a PrivatePoolV1Config.
Note that all the setters affecting config are
mutually exclusive.
Example
use google_cloud_build_v1::model::PrivatePoolV1Config;
let x = WorkerPool::new().set_private_pool_v1_config(PrivatePoolV1Config::default()/* use setters */);
assert!(x.private_pool_v1_config().is_some());Trait Implementations
Sourceimpl Clone for WorkerPool
impl Clone for WorkerPool
Sourcefn clone(&self) -> WorkerPool
fn clone(&self) -> WorkerPool
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for WorkerPool
impl Debug for WorkerPool
Sourceimpl Default for WorkerPool
impl Default for WorkerPool
Sourcefn default() -> WorkerPool
fn default() -> WorkerPool
Sourceimpl PartialEq for WorkerPool
impl PartialEq for WorkerPool
impl StructuralPartialEq for WorkerPool